# Cookies

D-Genies sets two essential cookies:

- A preference cookie called `wall`. It is an empty cookie that memorizes that the cookies warning message was displayed. It is set after clicking on "I understand" from the cookies warning message. It expires 180 days after it was set. It is not refreshed with new visits.
- A session cookie called `results`. It stores ids from previous jobs done with D-Genies in order to populate the "results" tab. It is set when a job is completed. It expires when the browser session ends. 

